function get_entrystate, entry

; Time at entry since an arbitrary t=0, seconds
; Radius at entry from centre of mass of planet minus reference radius, m
; Planetocentric north latitude at entry, deg
; Planetocentric east longitude at entry, deg
; Speed at entry in inertial, ie non-rotating, frame, m s-1
; Flight path angle below horizontal at entry in inertial frame, deg
; Flight path azimuth clockwise from north at entry in inertial frame, deg

; speed, fpa, azimuth from Towner email of 2002.02.28
; lat/lon assumed to give Isidis-ish landing
; Altitude assumed as 200km
if entry eq 'b2' then begin
return, double( $
 [0., 150*1e3, 10., 90., 5.75*1e3, 13.5, 77.] )
endif

; speed, fpa from Towner email of 2002.02.28
; alt from Lorenz, pers. comm. 2002.03.01
; lat, lon, azimuth from Rizk, pers. comm. 2002.03.01
if entry eq 'huy' then begin
return, double( $
 [0., 1270*1e3, -10.7, 156.4, 6.0*1e3, 64.0, 270.] )
endif

; Data from Spencer et al, 1999, J. Spacecraft Rockets, v36, p357
if entry eq 'mpf' then begin
junk = get_planet('mars')
rplanet = junk(4)
return, double( $
 [3110.4819-3110.4819, 3522200.0-rplanet, 22.6303, 337.9976, 7264.2, 14.0616, 253.1481] )
endif

; Data from Seiff et al, 1998, JGR, v103, p22857
; Probably relevant for slightly different frame, good enough for toy model
if entry eq 'gal' then return, double( $
 [0., 450*1e3, 6.5303, 4.9403, 47.4054*1e3, 8.4104, 90.+2.611] )

; Data from Colin, 1980, JGR, v85, p7575
; Probably relevant for slightly different frame, good enough for toy model
; Have assumed entry heading for 
; reasonable earth-to-entry trajectory in ecliptic plane
if entry eq 'pv' then return, double( $
 [0., 200*1e3, 5.5, 305.7, 11.5377*1e3, 32.37, 270.] )

if entry eq 'user' then return, double( $
 [0., 220*1e3, 0., 0., 10*1e3, 90., 0.] )

end
